ManifestChunk

Struct ManifestChunk 

pub struct ManifestChunk<S = String, Vs = Vec<S>, Vu8 = Vec<u8>> {
Show 13 fields pub key: S, pub contents: Vu8, pub hash: S, pub mime_type: S, pub src: Option<S>, pub file: S, pub css: Vs, pub assets: Vs, pub is_entry: bool, pub name: Option<S>, pub is_dynamic_entry: bool, pub imports: Vs, pub dynamic_imports: Vs,
}
Vite manifest chunk.

Where possible, use StaticManifestChunk and DynamicManifestChunk instead.

See Vite documentation

Generics

  • Generic S can be used to change type of strings in struct.
  • Generic Vs can be used to change type of array of strings.
  • Generic Vu8 can be used to change type of byte arrays (f.e. Vec<u8> or &[u8]).

Fields

key: S

The key of this chunk in manifest.

This field is added by vite-static and skipped during (de)serialization.

contents: Vu8

The contents of manifest chunk.

This field is added by vite-static and skipped during (de)serialization.

hash: S

Hash of this chunk. Derive macro uses BLAKE3 as hashing algorithm.

This field is added by vite-static and skipped during (de)serialization.

mime_type: S

Mime type of this chunk.

This field is added by vite-static and skipped during (de)serialization.

src: Option<S>

The input file name of this chunk/asset if known.

file: S

The output file name of this chunk/asset.

css: Vs

The list of CSS files imported by this chunk.

assets: Vs

The list of asset files imported by this chunk, excluding CSS files.

is_entry: bool

Whether this chunk or asset is an entry point

name: Option<S>

The name of this chunk/asset if known.

is_dynamic_entry: bool

Whether this chunk is a dynamic entry point

This field is only present in JS chunks.

imports: Vs

The list of statically imported chunks by this chunk

The values are the keys of the manifest. This field is only present in JS chunks.

dynamic_imports: Vs

The list of dynamically imported chunks by this chunk

The values are the keys of the manifest. This field is only present in JS chunks.