StaticManifestChunk

Type Alias StaticManifestChunk 

pub type StaticManifestChunk = ManifestChunk<&'static str, &'static [&'static str], &'static [u8]>;
Type alias for static ManifestChunk.

Aliased Type

pub struct StaticManifestChunk {
Show 13 fields pub key: &'static str, pub contents: &'static [u8], pub hash: &'static str, pub mime_type: &'static str, pub src: Option<&'static str>, pub file: &'static str, pub css: &'static [&'static str], pub assets: &'static [&'static str], pub is_entry: bool, pub name: Option<&'static str>, pub is_dynamic_entry: bool, pub imports: &'static [&'static str], pub dynamic_imports: &'static [&'static str],
}

Fields

key: &'static str

The key of this chunk in manifest.

This field is added by vite-static and skipped during (de)serialization.

contents: &'static [u8]

The contents of manifest chunk.

This field is added by vite-static and skipped during (de)serialization.

hash: &'static str

Hash of this chunk. Derive macro uses BLAKE3 as hashing algorithm.

This field is added by vite-static and skipped during (de)serialization.

mime_type: &'static str

Mime type of this chunk.

This field is added by vite-static and skipped during (de)serialization.

src: Option<&'static str>

The input file name of this chunk/asset if known.

file: &'static str

The output file name of this chunk/asset.

css: &'static [&'static str]

The list of CSS files imported by this chunk.

assets: &'static [&'static str]

The list of asset files imported by this chunk, excluding CSS files.

is_entry: bool

Whether this chunk or asset is an entry point

name: Option<&'static str>

The name of this chunk/asset if known.

is_dynamic_entry: bool

Whether this chunk is a dynamic entry point

This field is only present in JS chunks.

imports: &'static [&'static str]

The list of statically imported chunks by this chunk

The values are the keys of the manifest. This field is only present in JS chunks.

dynamic_imports: &'static [&'static str]

The list of dynamically imported chunks by this chunk

The values are the keys of the manifest. This field is only present in JS chunks.