pub struct ManifestChunk<S = String, Vs = Vec<S>, Vu8 = Vec<u8>> {}Expand description
Vite manifest chunk.
Where possible, use StaticManifestChunk and DynamicManifestChunk instead.
Generics
- Generic
Scan be used to change type of strings in struct. - Generic
Vscan be used to change type of array of strings. - Generic
Vu8can be used to change type of byte arrays (f.e.Vec<u8>or&[u8]).
Fields
key: SThe key of this chunk in manifest.
This field is added by vite-static and skipped during (de)serialization.
contents: Vu8The contents of manifest chunk.
This field is added by vite-static and skipped during (de)serialization.
hash: SHash of this chunk. Derive macro uses BLAKE3 as hashing algorithm.
This field is added by vite-static and skipped during (de)serialization.
mime_type: SMime type of this chunk.
This field is added by vite-static and skipped during (de)serialization.
src: Option<S>The input file name of this chunk/asset if known.
file: SThe output file name of this chunk/asset.
css: VsThe list of CSS files imported by this chunk.
assets: VsThe list of asset files imported by this chunk, excluding CSS files.
is_entry: boolWhether this chunk or asset is an entry point
name: Option<S>The name of this chunk/asset if known.
is_dynamic_entry: boolWhether this chunk is a dynamic entry point
This field is only present in JS chunks.
imports: VsThe list of statically imported chunks by this chunk
The values are the keys of the manifest. This field is only present in JS chunks.
dynamic_imports: VsThe list of dynamically imported chunks by this chunk
The values are the keys of the manifest. This field is only present in JS chunks.