pub type DynamicManifestChunk = ManifestChunk;Expand description
Type alias for dynamic allocated ManifestChunk.
Aliased Type
pub struct DynamicManifestChunk {Show 13 fields
pub key: String,
pub contents: Vec<u8>,
pub hash: String,
pub mime_type: String,
pub src: Option<String>,
pub file: String,
pub css: Vec<String>,
pub assets: Vec<String>,
pub is_entry: bool,
pub name: Option<String>,
pub is_dynamic_entry: bool,
pub imports: Vec<String>,
pub dynamic_imports: Vec<String>,
}Fields
key: StringThe key of this chunk in manifest.
This field is added by vite-static and skipped during (de)serialization.
contents: Vec<u8>The contents of manifest chunk.
This field is added by vite-static and skipped during (de)serialization.
hash: StringHash of this chunk. Derive macro uses BLAKE3 as hashing algorithm.
This field is added by vite-static and skipped during (de)serialization.
mime_type: StringMime type of this chunk.
This field is added by vite-static and skipped during (de)serialization.
src: Option<String>The input file name of this chunk/asset if known.
file: StringThe output file name of this chunk/asset.
css: Vec<String>The list of CSS files imported by this chunk.
assets: Vec<String>The list of asset files imported by this chunk, excluding CSS files.
is_entry: boolWhether this chunk or asset is an entry point
name: Option<String>The name of this chunk/asset if known.
is_dynamic_entry: boolWhether this chunk is a dynamic entry point
This field is only present in JS chunks.
imports: Vec<String>The list of statically imported chunks by this chunk
The values are the keys of the manifest. This field is only present in JS chunks.
dynamic_imports: Vec<String>The list of dynamically imported chunks by this chunk
The values are the keys of the manifest. This field is only present in JS chunks.